@@ -36,7 +36,7 @@ impl Object {
 	    let objects = string
 		.chars()
 		.skip(1)
-		.map(Object::Character)
+		.map(Self::Character)
 		.collect();
 
 	    Ok(Self::array_to_pair_list(objects))
@@ -47,6 +47,15 @@ impl Object {
         }
     }
 
+    pub fn string_to_lisp_string(string: &str) -> Self {
+	let objects = string
+	    .chars()
+	    .map(Self::Character)
+	    .collect();
+	
+	Self::array_to_pair_list(objects)
+    }
+
     pub fn pair_list_to_string(&self) -> Result<String, ()> {
 	let mut string = String::new();
 	let mut cur_object = self;
